Module wit

Module wit 

Modules

balius

Structs

HandleError
Worker
Auto-generated bindings for an instance a component which implements the world worker.
WorkerIndices
Auto-generated bindings for index of the exports of worker.
WorkerPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world worker.

Type Aliases

Config
Event
Response