Module http

Module http 

Structs

DnsErrorPayload
Defines the case payload type for DNS-error above:
FieldSizePayload
Defines the case payload type for HTTP-response-{header,trailer}-size above:
IncomingResponse
Represents an incoming HTTP response.
OutgoingRequest
Represents an outgoing HTTP Request.
RequestOptions
TlsAlertReceivedPayload
Defines the case payload type for TLS-alert-received above:

Enums

ErrorCode
HeaderError
Method
This type corresponds to HTTP standard Methods
Scheme
This type corresponds to HTTP standard Related Schemes.

Traits

Host

Functions

add_to_linker

Type Aliases

Duration
A duration of time, in nanoseconds.
FieldName
Field names are always strings.
FieldValue
Field values should always be ASCII strings. However, in reality, HTTP implementations often have to interpret malformed values, so they are provided as a list of bytes.
StatusCode
This type corresponds to the HTTP standard Status Code.