pub enum HeaderError {
InvalidSyntax,
Forbidden,
Immutable,
}Variants
InvalidSyntax
This error indicates that a field-name or field-value was
syntactically invalid when used with an operation that sets headers in a
fields.
Forbidden
This error indicates that a forbidden field-name was used when trying
to set a header in a fields.
Immutable
This error indicates that the operation on the fields was not
permitted because the fields are immutable.