pub struct OutgoingRequest {
pub scheme: Option<Scheme>,
pub authority: Option<String>,
pub path_and_query: Option<String>,
pub method: Method,
pub headers: Vec<(FieldName, FieldValue)>,
pub body: Option<Vec<u8>>,
}Expand description
Represents an outgoing HTTP Request.
Fields
scheme: Option<Scheme>The HTTP Related Scheme for the Request. When none, the
implementation may choose an appropriate default scheme.
The authority of the Request’s target URI. A value of none may be used
with Related Schemes which do not require an authority. The HTTP and
HTTPS schemes always require an authority.
path_and_query: Option<String>The combination of the HTTP Path and Query for the Request.
When none, this represents an empty Path and empty Query.
method: MethodThe method for the request
headers: Vec<(FieldName, FieldValue)>The http headers for the request
body: Option<Vec<u8>>The body (if any).