pub struct Worker { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world worker.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Worker::instantiate_asyncwhich only needs aStore,Component, andLinker. -
Alternatively you can create a
WorkerPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesWorkerPre::instantiate_asyncto create aWorker. -
If you’ve instantiated the instance yourself already then you can use
Worker::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Worker
impl Worker
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Worker>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Worker>where
_T: Send,
Convenience wrapper around WorkerPre::new and
WorkerPre::instantiate_async.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Worker>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Worker>
Convenience wrapper around WorkerIndices::new and
WorkerIndices::load.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
pub async fn call_init<S: AsContextMut>( &self, store: S, arg0: &Config, ) -> Result<()>
pub async fn call_handle<S: AsContextMut>( &self, store: S, arg0: u32, arg1: &Event, ) -> Result<Result<Response, HandleError>>