Driver to serve JSON-RPC requests.
This driver implements an HTTP server that listens for JSON-RPC requests and funnels them into the Runtime. The path of the request is used as the key to identify the worker that should handle the request. The JSON-RPC method field is used as the key to identify the particular Balius request for the worker. JSON-RPC params are mapped directly into Balius request params.
The JSON-RPC server is implemented as a Warp application and adheres to the JSON-RPC 2.0 spec.