Structs
- DnsError
Payload - Defines the case payload type for
DNS-errorabove: - Field
Size Payload - Defines the case payload type for
HTTP-response-{header,trailer}-sizeabove: - Incoming
Response - Represents an incoming HTTP response.
- Outgoing
Request - Represents an outgoing HTTP Request.
- Request
Options - TlsAlert
Received Payload - Defines the case payload type for
TLS-alert-receivedabove:
Enums
- Error
Code - Header
Error - Method
- This type corresponds to HTTP standard Methods
- Scheme
- This type corresponds to HTTP standard Related Schemes.
Traits
Functions
Type Aliases
- Duration
- A duration of time, in nanoseconds.
- Field
Name - Field names are always strings.
- Field
Value - Field values should always be ASCII strings. However, in reality, HTTP implementations often have to interpret malformed values, so they are provided as a list of bytes.
- Status
Code - This type corresponds to the HTTP standard Status Code.